@@ -1,6 +1,9 @@
 import numpy as np
 
-def calc_jacobian(frames: list, transformations: dict, jsize: int) -> np.array:
+def calc_jacobian(
+    frames: list, 
+    transformations: dict, 
+    jsize: int) -> np.array:
     """
     Args:
         frames (list): frames to compute jacobian
