@@ -99,7 +99,7 @@ class SingleArm(Robot):
         self.desired_frames = super().generate_desired_frame_recursive(self.desired_base_frame, self.eef_name)
         self._revolute_joint_names = sorted(self.get_revolute_joint_names(self.desired_frames))
 
-    def inverse_kin(self, current_joints, target_pose, method="LM", maxIter=1000):
+    def inverse_kin(self, current_joints, target_pose, method="LM", max_iter=1000):
         """
         Returns joint angles obtained by computing IK
         
@@ -107,7 +107,7 @@ class SingleArm(Robot):
             current_joints (sequence of float): input joint angles
             target_pose (np.array): goal pose to achieve
             method (str): two methods to calculate IK (LM: Levenberg-marquardt, NR: Newton-raphson)
-            maxIter (int): Maximum number of calculation iterations
+            max_iter (int): Maximum number of calculation iterations
 
         Returns:
             joints (np.array): target joint angles
@@ -117,7 +117,7 @@ class SingleArm(Robot):
             current_joints,
             target_pose,
             method,
-            maxIter)
+            max_iter)
         return joints
 
     def get_eef_pose(self, transformations=None):
@@ -180,20 +180,6 @@ class SingleArm(Robot):
 
         return transformations[self.eef_name].rot
 
-    def get_result_qpos(self, init_qpos, eef_pose, n_trials=5):
-        cnt = 0
-        is_limit_qpos = False
-        while cnt <= n_trials:
-            result_qpos = self.inverse_kin(np.random.randn(len(init_qpos)), eef_pose, "LM", 500)
-            is_limit_qpos = self.check_limit_joint(result_qpos)
-            if is_limit_qpos:
-                break
-            cnt += 1
-
-        if not is_limit_qpos:
-            return None
-        return result_qpos
-
     @property
     def base_name(self):
         return self._base_name
