@@ -12,30 +12,30 @@ def apply_robot_to_collision_manager(c_manager, robot, fk=None, geom="visual"):
                 mesh_name = robot.links[link].visual.gparam.get('filename')
                 file_name = c_manager.mesh_path + mesh_name
                 mesh = trimesh.load_mesh(file_name)
-                A2B = np.dot(transformation.h_mat, robot.links[link].visual.offset.h_mat)
+                h_mat = np.dot(transformation.h_mat, robot.links[link].visual.offset.h_mat)
                 if c_manager._filter_names:
-                    c_manager.set_transform(name=robot.links[link].name, transform=A2B)
+                    c_manager.set_transform(name=robot.links[link].name, transform=h_mat)
                 else:
                     c_manager.add_object(
                         name=robot.links[link].name, 
                         gtype="mesh",
                         gparam=mesh,
-                        transform=A2B)
+                        transform=h_mat)
 
         if geom == "collision":
             if robot.links[link].collision.gtype == "mesh":
                 mesh_name = robot.links[link].collision.gparam.get('filename')
                 file_name = c_manager.mesh_path + mesh_name
                 mesh = trimesh.load_mesh(file_name)
-                A2B = np.dot(transformation.h_mat, robot.links[link].collision.offset.h_mat)
+                h_mat = np.dot(transformation.h_mat, robot.links[link].collision.offset.h_mat)
                 if c_manager._filter_names:
-                    c_manager.set_transform(name=robot.links[link].name, transform=A2B)
+                    c_manager.set_transform(name=robot.links[link].name, transform=h_mat)
                 else:
                     c_manager.add_object(
                         name=robot.links[link].name, 
                         gtype="mesh",
                         gparam=mesh,
-                        transform=A2B)
+                        transform=h_mat)
     return c_manager
 
 
@@ -52,7 +52,7 @@ def apply_robot_to_scene(mesh_path=None, scene=None, robot=None, fk=None, geom="
                 mesh_name = robot.links[link].visual.gparam.get('filename')
                 file_name = mesh_path + mesh_name
                 mesh = trimesh.load_mesh(file_name)
-                A2B = np.dot(transformation.h_mat, robot.links[link].visual.offset.h_mat)
+                h_mat = np.dot(transformation.h_mat, robot.links[link].visual.offset.h_mat)
                 color = robot.links[link].visual.gparam.get('color')
 
                 if color is None:
@@ -61,14 +61,14 @@ def apply_robot_to_scene(mesh_path=None, scene=None, robot=None, fk=None, geom="
                     color = np.array([color for color in color.values()]).flatten()
 
                 mesh.visual.face_colors = color
-                scene.add_geometry(mesh, transform=A2B)  
+                scene.add_geometry(mesh, transform=h_mat)  
 
         if geom == "collision":
             if robot.links[link].collision.gtype == "mesh":
                 mesh_name = robot.links[link].collision.gparam.get('filename')
                 file_name = mesh_path + mesh_name
                 mesh = trimesh.load_mesh(file_name)
-                A2B = np.dot(transformation.h_mat, robot.links[link].collision.offset.h_mat)
+                h_mat = np.dot(transformation.h_mat, robot.links[link].collision.offset.h_mat)
                 color = robot.links[link].collision.gparam.get('color')
 
                 if color is None:
@@ -77,7 +77,7 @@ def apply_robot_to_scene(mesh_path=None, scene=None, robot=None, fk=None, geom="
                     color = np.array([color for color in color.values()]).flatten()
                 
                 mesh.visual.face_colors = color
-                scene.add_geometry(mesh, transform=A2B)      
+                scene.add_geometry(mesh, transform=h_mat)      
     scene.set_camera(np.array([np.pi/2, 0, np.pi/2]), 5, resolution=(1024, 512))
     return scene
 
